function [UCovZ,UCovZs,OutVec,sOutvec,CovOutVec] = vardecompvar(P,s,Cov);

global h;      

% reports variance decomposition for ordered VARs
% with standard errors for z = theta + Theta*Y and Y follows a VAR
% the data *must* be arranged so that the first elements of
% z are y, in order


% function handle so only the parameters are needed
irh = @(p) ir(p,s);  

% point estimate
[f0 sOutVec] = irh(P);

% gradient
paramdim  = size(P',2);
ndx       = reshape((1:paramdim),paramdim,1);
for i = 1:paramdim
    di = h*(ndx==i)';
    ft = irh(P+di');
  G(:,i) = (ft'-f0')/(h);
end;

% done, just reorganize
OutVec = f0;
sOutvec = sOutVec;
CovOutVec = G*Cov*G';
[UCovZ] = imvec(f0,sOutVec);
[UCovZs] = imvec(sqrt(diag(CovOutVec)),sOutVec);

% subfunction

function [OutVec,sOutVec] = ir(P,s);

[theta,Theta,mu,A,Cov] = imvec(P,s);

k = size(A,1);
n = size(theta,1);

EZ  = theta + Theta*inv(eye(k)-A)*mu;
VZ  = Theta*reshape(inv(eye(k^2)-kron(A,A))*reshape(Cov,k^2,1),k,k)*Theta';

RZ  = VZ ./ (sqrt(diag(VZ))*sqrt(diag(VZ))');

[OutVec, sOutVec] = mvec(VZ);